@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATION_BRIDGE_H
-#define KDECORATION2_DECORATION_BRIDGE_H
+#pragma once
 
 #include <QObject>
 
@@ -49,5 +48,3 @@ protected:
 } // namespace
 
 Q_DECLARE_METATYPE(KDecoration2::DecorationBridge *)
-
-#endif
